@@ -13,7 +13,7 @@ our @EXPORT = qw(
 
 use Data::Roundtrip qw/perl2dump no-unicode-escape-permanently/;
  
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 # caller can set this to 0,1,2,3
 our $VERBOSE_DOMops = 0;
@@ -343,7 +343,7 @@ EOJ
 	// now call the js callback function on those matched (not the children, if you want children then do it in the cb)
 	let cb_results = {};
 	for(let acbname of known_callbacks){
-		// this *shit* does not work: if( ! acbname in cb_functions ){ continue; }
+		// this *crap* does not work: if( ! acbname in cb_functions ){ continue; }
 		// and caused me a huge waste of time
 		if( ! cb_functions[acbname] ){ continue; }
 		if( VERBOSE_DOMops > 1 ){ console.log("found callback for '"+acbname+"' and processing its code blocks ..."); }
@@ -494,23 +494,44 @@ sub zap {
 
 =head1 NAME
 
-WWW::Mechanize::Chrome::DOMops - Operations on the DOM
+WWW::Mechanize::Chrome::DOMops - Operations on the DOM loaded in Chrome
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
 This module provides a set of tools to operate on the DOM of the
-provided L<WWW::Mechanize::Chrome>. Currently,
-supported operations are: C<find()> to find HTML elements
-and C<zap()> to delete HTML elements.
+provided L<WWW::Mechanize::Chrome> object. Currently,
+supported operations are:
+
+=over 4
+
+=item * C<find()> : finds HTML elements
+
+=item * C<zap()> : deletes HTML elements
+
+=back
 
 The selection of the HTML elements in the DOM
-can be done in various ways,
-e.g. by tag, id, name, class or by a CSS selector. There
-is more information in section L<ELEMENT SELECTORS>.
+can be done in various ways:
+
+=over 4
+
+=item * by a B<CSS selector>,
+
+=item * by B<tag>,
+
+=item * by B<class>.
+
+=item * by B<id>,
+
+=item * by B<name>.
+
+=back
+
+There is more information about this in section L<ELEMENT SELECTORS>.
 
 Here are some usage scenaria:
 
@@ -520,8 +541,9 @@ Here are some usage scenaria:
     $WWW::Mechanize::Chrome::VERBOSE_DOMops = 3;
 
     # First, create a mech object and load a URL on it
+    # Note: you need google-chrome binary installed in your system!
     my $mechobj = WWW::Mechanize::Chrome->new();
-    $mechobj->get('https://www.xyz.com');
+    $mechobj->get('https://www.bbbbbbbbb.com');
 
     # find elements in the DOM, select by id, tag, name, or 
     # by a CSS selector.
@@ -540,17 +562,21 @@ Here are some usage scenaria:
        'element-cssselector' => 'a-css-selector',
        # specifies that we should use the union of the above sets
        # hence the *OR* in above comment
-       || => 1,
+       '||' => 1,
        # this says to find all elements whose class
        # is such-and-such AND element tag is such-and-such
-       # && => 1 means to calculate the INTERSECTION of all
+       # '&&' => 1 means to calculate the INTERSECTION of all
        # individual matches.
        
        # optionally run javascript code on all those elements matched
        'find-cb-on-matched' => [
          {
            'code' =><<'EOJS',
-console.log("found this element "+htmlElement.tagName); return 1;
+  // the element to operate on is 'htmlElement'
+  console.log("operating on this element "+htmlElement.tagName);
+  // this is returned back in the results of find() under
+  // key "find-cb-on-matched"
+  return 1;
 EOJS
            'name' => 'func1'
          }, {...}
@@ -560,7 +586,11 @@ EOJS
        'find-cb-on-matched-and-their-children' => [
          {
            'code' =><<'EOJS',
-console.log("found this element "+htmlElement.tagName); return 1;
+  // the element to operate on is 'htmlElement'
+  console.log("operating on this element "+htmlElement.tagName);
+  // this is returned back in the results of find() under
+  // key "find-cb-on-matched" notice the complex data
+  return {"abc":"123",{"xyz":[1,2,3]}};
 EOJS
            'name' => 'func2'
          }
@@ -573,7 +603,7 @@ EOJS
        # or ask it to randomise that id a bit to avoid collisions
        'insert-id-if-none-random' => '_prefix_id',
 
-       # optionally output the javascript code to a file for debugging
+       # optionally, also output the javascript code to a file for debugging
        'js-outfile' => 'output.js',
     });
 
@@ -694,11 +724,16 @@ code (which is evaluated within the mech object) to a file.
 
 B<JAVASCRIPT HELPERS>
 
-There is one javascript function which can be called from any of the
-callbacks as C<getAllChildren(anHtmlElement)>. It returns
+There is one javascript function available to all user-specified callbacks:
+
+=over 2
+
+=item * C<getAllChildren(anHtmlElement)> : it returns
 back an array of HTML elements which are the children (at any depth)
 of the given C<anHtmlElement>.
 
+=back
+
 B<RETURN VALUE>:
 
 The returned value is a hashref with at least a C<status> key
@@ -865,6 +900,13 @@ by at least one of the selectors specified.
 
 =back
 
+=head1 DEPENDENCIES
+
+This module depends on L<WWW::Mechanize::Chrome> which, in turn,
+depends on the C<google-chrome> executable be installed on the
+host computer. See L<WWW::Mechanize::Chrome::Install> on
+how to install the executable.
+
 =head1 AUTHOR
 
 Andreas Hadjiprocopis, C<< <bliako at cpan.org> >>
@@ -886,8 +928,6 @@ You can also look for information at:
 
 =over 4
 
-=item * L<WWW::Mechanize::Chrome>
-
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Mechanize-Chrome-DOMops>
@@ -913,7 +953,8 @@ Almaz
 
 =head1 ACKNOWLEDGEMENTS
 
-L<CORION> for publishing  L<WWW::Mechanize::Chrome>
+L<CORION> for publishing  L<WWW::Mechanize::Chrome> and all its
+contributors.
 
 
 =head1 LICENSE AND COPYRIGHT
